@@ -34,10 +34,10 @@ import (
 	docker "github.com/docker/docker/api/types/container"
 	"github.com/docker/docker/api/types/network"
 	"github.com/docker/go-connections/nat"
-	l "github.com/rancher/k3d/v5/pkg/logger"
-	runtimeErr "github.com/rancher/k3d/v5/pkg/runtimes/errors"
-	k3d "github.com/rancher/k3d/v5/pkg/types"
-	"github.com/rancher/k3d/v5/pkg/types/fixes"
+	l "github.com/k3d-io/k3d/v5/pkg/logger"
+	runtimeErr "github.com/k3d-io/k3d/v5/pkg/runtimes/errors"
+	k3d "github.com/k3d-io/k3d/v5/pkg/types"
+	"github.com/k3d-io/k3d/v5/pkg/types/fixes"
 	"inet.af/netaddr"
 
 	dockercliopts "github.com/docker/cli/opts"
@@ -57,6 +57,10 @@ func TranslateNodeToContainer(node *k3d.Node) (*NodeInDocker, error) {
 	hostConfig := docker.HostConfig{
 		Init:       &init,
 		ExtraHosts: node.ExtraHosts,
+		// Explicitly require bridge networking. Podman incorrectly uses
+		// slirp4netns when running rootless, therefore for rootless podman to
+		// work, this must be set.
+		NetworkMode: "bridge",
 	}
 	networkingConfig := network.NetworkingConfig{}
 
